@@ -1,4 +1,4 @@
-/* $Id: directory-handle.h,v 1.2 2003/04/30 18:25:18 murrayc Exp $ */
+/* $Id: directory-handle.h,v 1.7 2004/02/13 18:22:29 murrayc Exp $ */
 
 /* Copyright 2003 gnome-vfsmm Development Team
  *
@@ -26,6 +26,7 @@
 #include <libgnomevfsmm/uri.h>
 #include <libgnomevfsmm/file-info.h>
 #include <libgnomevfsmm/enums.h>
+#include <libgnomevfsmm/exception.h>
 #include <libgnomevfs/gnome-vfs-directory.h>
 
 
@@ -47,7 +48,7 @@ public:
 
 
   /// e.g. bool on_visit(const Glib::ustring& rel_path, const Glib::RefPtr<const FileInfo>& info, bool recursing_will_loop, bool& recurse);
-  typedef SigC::Slot4<bool, const Glib::ustring&, const Glib::RefPtr<const FileInfo>&, bool, bool&> SlotVisit;
+  typedef sigc::slot<bool, const Glib::ustring&, const Glib::RefPtr<const FileInfo>&, bool, bool&> SlotVisit;
 
   /* 
   typedef gboolean (* GnomeVFSDirectoryVisitFunc)	 (const gchar *rel_path,
@@ -60,31 +61,11 @@ public:
   static void visit(const Glib::ustring& uri, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception);
   static void visit(const Glib::RefPtr<const Uri>& uri, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception);
  
+  static void visit_files(const Glib::ustring& uri, const Glib::ListHandle<Glib::ustring>& file_list, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception);
+  static void visit_files(const Glib::RefPtr<const Uri>& uri, const Glib::ListHandle<Glib::ustring> & file_list, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception);
 
-/*
-GnomeVFSResult	gnome_vfs_directory_visit_files
-					(const gchar *text_uri,
-					 GList *file_list,
-					 GnomeVFSFileInfoOptions info_options,
-					 GnomeVFSDirectoryVisitOptions visit_options,
-					 GnomeVFSDirectoryVisitFunc callback,
-					 gpointer data);
+  static void list_load(const Glib::ListHandle<Glib::ustring>& list, const Glib::ustring& text_uri, FileInfoOptions info_options) throw(exception);
 
-GnomeVFSResult	gnome_vfs_directory_visit_files_at_uri
-					(GnomeVFSURI *uri,
-					 GList *file_list,
-					 GnomeVFSFileInfoOptions info_options,
-					 GnomeVFSDirectoryVisitOptions visit_options,
-					 GnomeVFSDirectoryVisitFunc callback,
-					 gpointer data);
-
-GnomeVFSResult gnome_vfs_directory_list_load
-					(GList **list,
-				         const gchar *text_uri,
-				         GnomeVFSFileInfoOptions options);
-*/
-
-                 
   void open(const Glib::ustring& text_uri, FileInfoOptions options = FILE_INFO_DEFAULT) throw(exception);
   void open(const Glib::RefPtr<const Uri>& uri, FileInfoOptions options = FILE_INFO_DEFAULT) throw(exception);
 
@@ -98,9 +79,7 @@ GnomeVFSResult gnome_vfs_directory_list_load
 
 
 protected:
-
-  static void handle_result(GnomeVFSResult result) throw(exception);
-  
+ 
   GnomeVFSDirectoryHandle* gobj_;
 };
 
